==> nmh-0.08.tar.gz: nmh-0.08/h/prototypes.h <==

/*
 * prototypes.h -- various prototypes
 *
 * $Id$
 */

/*
 * missing system prototypes
 */
#ifndef HAVE_TERMCAP_H
extern int tgetent (char *bp, char *name);
extern int tgetnum (char *id);
extern int tgetflag (char *id);
extern char *tgetstr (char *id, char **area);
extern char *tgoto (char *cm, int destcol, int destline);
extern int tputs (char *cp, int affcnt, int (*outc) (int));
#endif

/*
 * prototype from config.h
 */
char *etcpath(char *);

/*
 * prototypes from the MH subroutine library
 */
char *add (char *, char *);
void adios (char *, char *, ...);
void admonish (char *, char *, ...);
void advertise (char *, char *, char *, va_list);
void advise (char *, char *, ...);
void ambigsw (char *, struct swit *);
int atooi(char *);
char **brkstring (char *, char *, char *);
void closefds(int);
char *concat (char *, ...);
char *copy(char *, char *);
char **copyip (char **, char **);
void cpydata (int, int, char *, char *);
void cpydgst (int, int, char *, char *);
void discard (FILE *);
void done (int);
int fdcompare (int, int);
int gans (char *, struct swit *);
char **getans (char *, struct swit *);
int getanswer (char *);
char *getcpy (char *);
int m_atoi (char *);
char *m_backup (char *);
int m_convert (struct msgs *, char *);
int m_delete (char *);
char *m_draft (char *, char *, int, int *);
void m_eomsbr (int (*)());
char *m_find(char *);
void m_fmsg (struct msgs *);
void m_foil (char *);
void m_getdefs(void);
int m_getfld (int, unsigned char *, unsigned char *, int, FILE *);
char *m_getfolder(void);
int m_gmprot (void);
struct msgs *m_gmsg (char *);
char *m_maildir (char *);
char *m_mailpath (char *);
char *m_name (int);
int m_putenv (char *, char *);
void m_readefs (struct node **, FILE *, char *, int);
struct msgs *m_remsg ();
void m_replace (char *, char *);
char *m_scratch (char *, char *);
char *m_seq (struct msgs *, char *);
int m_seqadd (struct msgs *, char *, int, int);
char *m_seqbits (struct msgs *);
int m_seqdel (struct msgs *, char *, int);
int m_seqflag (struct msgs *, char *);
int m_seqnew (struct msgs *, char *, int);
void m_setcur (struct msgs *, int);
void m_setseq (struct msgs *);
void m_setvis (struct msgs *, int);
void m_sync (struct msgs *);
char *m_tmpfil (char *);
void m_unknown(FILE *);
void m_update(void);
int makedir (char *);
char *new_fs (char *, char *, char *);
char *path(char *, int);
int peekc(FILE *ib);
int pidwait (pid_t, int);
int pidstatus (int, FILE *, char *);
void print_help (char *, struct swit *);
void print_sw (char *, struct swit *, char *);
void print_version (char *);
void push (void);
char *pwd (void);
char *r1bindex(char *, int);
int refile (char **, char *);
int remdir (char *);
int showfile (char **, char *);
int smatch(char *, struct swit *);
char *sprintb (char *, unsigned, char *);
int ssequal (char *, char *);
int stringdex (char *, char *);
char *trimcpy (char *);
int uleq (char *, char *);
int unputenv (char *);
int uprf (char *, char *);
int vfgets (FILE *, char **);

/*
 * prototypes for compat functions in library
 */
#ifndef HAVE_STRERROR
char *strerror (int);
#endif


/*
 * some prototypes for address parsing system
 * (others are in addrsbr.h)
 */
char *LocalName(void);
char *SystemName(void);
char *UucpChan(void);
char *OfficialName(char *);

==> nmh-0.10.tar.gz: nmh-0.10/h/prototypes.h <==

/*
 * prototypes.h -- various prototypes
 *
 * $Id$
 */

/*
 * missing system prototypes
 */
#ifndef HAVE_TERMCAP_H
extern int tgetent (char *bp, char *name);
extern int tgetnum (char *id);
extern int tgetflag (char *id);
extern char *tgetstr (char *id, char **area);
extern char *tgoto (char *cm, int destcol, int destline);
extern int tputs (char *cp, int affcnt, int (*outc) (int));
#endif

/*
 * prototype from config.h
 */
char *etcpath(char *);

/*
 * prototypes from the nmh subroutine library
 */
char *add (char *, char *);
void adios (char *, char *, ...);
void admonish (char *, char *, ...);
void advertise (char *, char *, char *, va_list);
void advise (char *, char *, ...);
void ambigsw (char *, struct swit *);
int atooi(char *);
char **brkstring (char *, char *, char *);
void closefds(int);
char *concat (char *, ...);
char *copy(char *, char *);
char **copyip (char **, char **);
void cpydata (int, int, char *, char *);
void cpydgst (int, int, char *, char *);
void discard (FILE *);
void done (int);
int fdcompare (int, int);
int gans (char *, struct swit *);
char **getans (char *, struct swit *);
int getanswer (char *);
char *getcpy (char *);
int m_atoi (char *);
char *m_backup (char *);
int m_convert (struct msgs *, char *);
int m_delete (char *);
char *m_draft (char *, char *, int, int *);
void m_eomsbr (int (*)());
char *m_find(char *);
void m_fmsg (struct msgs *);
void m_foil (char *);
void m_getdefs(void);
int m_getfld (int, unsigned char *, unsigned char *, int, FILE *);
char *m_getfolder(void);
int m_gmprot (void);
struct msgs *m_gmsg (char *);
char *m_maildir (char *);
char *m_mailpath (char *);
char *m_name (int);
int m_putenv (char *, char *);
void m_readefs (struct node **, FILE *, char *, int);
struct msgs *m_remsg ();
void m_replace (char *, char *);
char *m_scratch (char *, char *);
char *m_seq (struct msgs *, char *);
int m_seqadd (struct msgs *, char *, int, int);
char *m_seqbits (struct msgs *);
int m_seqdel (struct msgs *, char *, int);
int m_seqflag (struct msgs *, char *);
int m_seqnew (struct msgs *, char *, int);
void m_setcur (struct msgs *, int);
void m_setseq (struct msgs *);
void m_setvis (struct msgs *, int);
void m_sync (struct msgs *);
char *m_tmpfil (char *);
void m_unknown(FILE *);
void m_update(void);
int makedir (char *);
char *new_fs (char *, char *, char *);
char *path(char *, int);
int peekc(FILE *ib);
int pidwait (pid_t, int);
int pidstatus (int, FILE *, char *);
void print_help (char *, struct swit *);
void print_sw (char *, struct swit *, char *);
void print_version (char *);
void push (void);
char *pwd (void);
char *r1bindex(char *, int);
int refile (char **, char *);
int remdir (char *);
int showfile (char **, char *);
int smatch(char *, struct swit *);
char *sprintb (char *, unsigned, char *);
int ssequal (char *, char *);
int stringdex (char *, char *);
char *trimcpy (char *);
int uleq (char *, char *);
int unputenv (char *);
int uprf (char *, char *);
int vfgets (FILE *, char **);

#ifdef RPATHS
int get_returnpath (char *, char *);
#endif

/*
 * prototypes for compat functions in library
 */
#ifndef HAVE_STRERROR
char *strerror (int);
#endif


/*
 * some prototypes for address parsing system
 * (others are in addrsbr.h)
 */
char *LocalName(void);
char *SystemName(void);
char *UucpChan(void);
char *OfficialName(char *);
